<p align ="center">
<img width=200 src = "./images/fr_logo.png">
</p>


<div align="center">

[![Downloads](https://static.pepy.tech/badge/flashrank)](https://pepy.tech/project/flashrank)
[![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)]()
[![license]( https://img.shields.io/badge/License-Apache-blue.svg)](https://opensource.org/licenses/Apache2.0)
[![package]( https://img.shields.io/badge/Package-PYPI-blue.svg)](https://pypi.org/project/FlashRank/)[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.11093524.svg)](https://doi.org/10.5281/zenodo.11093524)

</div>

<hr>

<div align="center">

  <h4 align="center">
    <b>Low latency, High Accuracy, Custom Query routers for Humans and Agents </b>
    <br />
  </h4>
</div>



### I want to use it
### I want to know how it works
### I want to see the detailed empirical evals
### Roadmap
### Limitations
### Citations